from django.db import models
from django.utils.translation import ugettext as _

class Release(models.Model):
    """
    A snapshot of a project with a unique name.

    Releases are used to coordinate testing and help with project management. A
    release is "done" once released_date is set. After that it should not be
    changed any further.
    """
    
    project = models.ForeignKey(
        "lava_data_store.Project",
        null=False,
        blank=False,
        related_name="releases",
        help_text=_(u"Release to project association"))

    name = models.CharField(
        null=False,
        blank=True,
        max_length=100,
        help_text=_(u"Release name, if any"))

    expected_date = models.DateField(
        null=False,
        blank=False,
        help_text=_(u"When this release is expected to happen"))

    released_date = models.DateTimeField(
        null=True,
        blank=True,
        help_text=_(u"When this release has actually happened"))

    def __unicode__(self):
        return "{project.name} {name_or_date}".format(
            project=self.project,
            name_or_date=self.name or self.expected_date.strftime("%y.%m"))

    @models.permalink
    def get_absolute_url(self):
        return ('lava.release.detail', [self.project.pk, self.pk])

    class Meta:
        app_label = 'lava_data_store'
