from django.contrib.auth.decorators import login_required
from django.http import HttpResponse, HttpResponseRedirect, HttpResponseForbidden
from django.shortcuts import get_object_or_404
from django.template import RequestContext, loader
from django.utils.translation import ugettext as _
from django.views.generic.list_detail import object_list, object_detail

from lava_data_store.models import Project 
from lava_data_store.models import Release
from lava_data_store.models import Image 


def image_list(request, project_id, release_id):
    project = get_object_or_404(
        Project.objects.accessible_by_principal(request.user), 
        pk=project_id)
    release = get_object_or_404(
        project.releases.all(),
        pk=release_id)
    return object_list(
        request,
        queryset=release.images.all().order_by('name'),
        template_name="lava_data_store/image_list.html",
        template_object_name="image",
        extra_context={
            'project': project,
            'release': release})


def image_detail(request, project_id, release_id, image_id):
    project = get_object_or_404(
        Project.objects.accessible_by_principal(request.user), 
        pk=project_id)
    release = get_object_or_404(
        project.releases.all(),
        pk=release_id)
    image = get_object_or_404(
        release.images.all(),
        pk=image_id)
    template_name = "lava_data_store/image_detail.html"
    t = loader.get_template(template_name)
    c = RequestContext(request, {
        'project': project,
        'release': release,
        'image': image,
        'belongs_to_user': project.is_owned_by(request.user),
    })
    return HttpResponse(t.render(c))
